---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**What happened**:

**What you expected to happen**:

**How to reproduce it (as minimally and precisely as possible)**:

**Anything else we need to know?**:

**Environment**:
- Output of `vunnel version`:
- OS (e.g: `cat /etc/os-release` or similar):
